==> huaweicloudsdkdataartsfabric-3.1.130-py2.py3-none-any.whl: huaweicloudsdkdataartsfabric/v1/model/list_fabric_project_tags_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListFabricProjectTagsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tags': 'list[ResourceTagParam]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'tags': 'tags',
        'x_request_id': 'X-request-id'
    }

    def __init__(self, tags=None, x_request_id=None):
        """ListFabricProjectTagsResponse

        The model defined in huaweicloud sdk

        :param tags: 标签列表
        :type tags: list[:class:`huaweicloudsdkdataartsfabric.v1.ResourceTagParam`]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListFabricProjectTagsResponse, self).__init__()

        self._tags = None
        self._x_request_id = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def tags(self):
        """Gets the tags of this ListFabricProjectTagsResponse.

        标签列表

        :return: The tags of this ListFabricProjectTagsResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsfabric.v1.ResourceTagParam`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ListFabricProjectTagsResponse.

        标签列表

        :param tags: The tags of this ListFabricProjectTagsResponse.
        :type tags: list[:class:`huaweicloudsdkdataartsfabric.v1.ResourceTagParam`]
        """
        self._tags = tags

    @property
    def x_request_id(self):
        """Gets the x_request_id of this ListFabricProjectTagsResponse.

        :return: The x_request_id of this ListFabricProjectTagsResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        """Sets the x_request_id of this ListFabricProjectTagsResponse.

        :param x_request_id: The x_request_id of this ListFabricProjectTagsResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListFabricProjectTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsfabric-3.1.152-py2.py3-none-any.whl: huaweicloudsdkdataartsfabric/v1/model/list_fabric_project_tags_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListFabricProjectTagsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'tags': 'list[ResourceTagParam]',
        'x_request_id': 'str'
    }

    attribute_map = {
        'tags': 'tags',
        'x_request_id': 'X-request-id'
    }

    def __init__(self, tags=None, x_request_id=None):
        r"""ListFabricProjectTagsResponse

        The model defined in huaweicloud sdk

        :param tags: 标签列表
        :type tags: list[:class:`huaweicloudsdkdataartsfabric.v1.ResourceTagParam`]
        :param x_request_id: 
        :type x_request_id: str
        """
        
        super(ListFabricProjectTagsResponse, self).__init__()

        self._tags = None
        self._x_request_id = None
        self.discriminator = None

        if tags is not None:
            self.tags = tags
        if x_request_id is not None:
            self.x_request_id = x_request_id

    @property
    def tags(self):
        r"""Gets the tags of this ListFabricProjectTagsResponse.

        标签列表

        :return: The tags of this ListFabricProjectTagsResponse.
        :rtype: list[:class:`huaweicloudsdkdataartsfabric.v1.ResourceTagParam`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        r"""Sets the tags of this ListFabricProjectTagsResponse.

        标签列表

        :param tags: The tags of this ListFabricProjectTagsResponse.
        :type tags: list[:class:`huaweicloudsdkdataartsfabric.v1.ResourceTagParam`]
        """
        self._tags = tags

    @property
    def x_request_id(self):
        r"""Gets the x_request_id of this ListFabricProjectTagsResponse.

        :return: The x_request_id of this ListFabricProjectTagsResponse.
        :rtype: str
        """
        return self._x_request_id

    @x_request_id.setter
    def x_request_id(self, x_request_id):
        r"""Sets the x_request_id of this ListFabricProjectTagsResponse.

        :param x_request_id: The x_request_id of this ListFabricProjectTagsResponse.
        :type x_request_id: str
        """
        self._x_request_id = x_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListFabricProjectTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
